# AutoLinkPipe
Finds links in text input and turns them into HTML links.

```
{{ value | autolink [ : target ] }}
```

## Input value
**value**: `String`  
The input text.

## Parameters
**target**: `String`   
The optional window or named frame to open links in.

## Usage notes
The following code shows how the pipe transforms plain links into HTML anchors:

```dart
import 'package:angular/angular.dart';
import 'package:ngx_core/ngx_core.dart';

@Component(
  pipes: [ngxPipes],
  selector: 'autolink-pipe',
  template: '''
    <div [innerHTML]="value | autolink"></div>
    <div [innerHTML]="value | autolink: '_blank'"></div>
  '''
)
class AutoLinkPipeComponent {
  String value = '''
    Pretty text with some links:
    https://belin.io/index.html?search=foo#bar,
    mailto:us@somewhere.org,
    another@somewhere.org,
    and one more: ftp://127.0.0.1/.
  ''';
}
```

The rendering of the template will looks like this:

```html
<div>
  Pretty text with some links:
  <a href="https://belin.io/index.html?search=foo#bar">https://belin.io/index.html?search=foo#bar</a>,
  <a href="mailto:us@somewhere.org">us@somewhere.org</a>,
  <a href="mailto:another@somewhere.org">another@somewhere.org</a>,
  and one more: <a href="ftp://127.0.0.1/">ftp://127.0.0.1/</a>.
</div>
<div>
  Pretty text with some links:
  <a href="https://belin.io/index.html?search=foo#bar" target="_blank">https://belin.io/index.html?search=foo#bar</a>,
  <a href="mailto:us@somewhere.org" target="_blank">us@somewhere.org</a>,
  <a href="mailto:another@somewhere.org" target="_blank">another@somewhere.org</a>,
  and one more: <a href="ftp://127.0.0.1/" target="_blank">ftp://127.0.0.1/</a>.
</div>
```
