# EncodeUriPipe
Encodes strings using percent-encoding to make them safe for literal use as a URI component.

```
{{ value | encodeUri }}
```

## Input value
**value**: `String`  
The string to encode.

## Usage notes
The following code shows how the pipe encodes strings using percent-encoding:

```dart
import 'package:angular/angular.dart';
import 'package:ngx_core/ngx_core.dart';

@Component(
  pipes: [ngxPipes],
  selector: 'encodeuri-pipe',
  template: '''
    <a href="mailto:support@example.com?subject={{'Hello World!' | encodeUri}}">Send an e-mail</a>
    <a href="https://twitter.com/intent/tweet?text={{title | encodeUri}}&amp;url={{url | encodeUri}}">Share on Twitter</a>
  '''
)
class EncodeUriPipeComponent {
  String title = 'Cédric Belin';
  String url = 'https://belin.io';
}
```

The rendering of the template will looks like this:

```html
<a href="mailto:support@example.com?subject=Hello%20World!">Send an e-mail</a>
<a href="https://twitter.com/intent/tweet?text=C%C3%A9dric%20Belin&amp;url=https%3A%2F%2Fbelin.io">Share on Twitter</a>
```
