# SafePipe
Bypasses security and trusts a given value to be safe.

```
{{ value | safe [ : context ] }}
```

!!! warning
    Carefully check and audit all values going into this pipe. Make sure any data is appropriately escaped for the specified security context. For more detail, see the [Security Guide](https://angulardart.dev/guide/security).

## Input value
**value**: `String`  
The value to trust.

## Parameters
**context**: [`TemplateSecurityContext`](https://angulardart.dev/api/angular/angular.security/TemplateSecurityContext-class)  
The security context to apply to the safe value.

!!! info
    By default, the context `TemplateSecurityContext.html` is applied.

## Usage notes
The following code shows how the pipe transforms the input value into a [`SafeValue`](https://angulardart.dev/api/angular/angular.security/SafeValue-class):

```dart
import 'package:angular/angular.dart';
import 'package:angular/security.dart';
import 'package:ngx_core/ngx_core.dart';

@Component(
  exports: [TemplateSecurityContext],
  pipes: [ngxPipes],
  selector: 'safe-pipe',
  template: '''
    <div [innerHTML]="html | safe: TemplateSecurityContext.html"></div>
    <a [href]="url | safe: TemplateSecurityContext.url"></a>
  '''
)
class SafePipeComponent {
  String html = '<script>alert("Foo!")</script>';
  String url = "javascript:alert('Foo!')";
}
```

The rendering of the template will looks like this:

```html
<div><script>alert("Foo!")</script></div>
<a href="javascript:alert('Foo!')"></a>
```
