part of '../../ngx_core.dart';

/// Navigates to the previous page in the session history when the underlying element is clicked.
@Directive(exportAs: 'goBack', selector: '[goBack]')
class GoBack {
  /// Creates a new `goBack` directive.
  GoBack(this._element, this._location, this._router);

  /// The underlying HTML element.
  final dom.Element _element;

  /// The service providing access to the browser's URL.
  final Location _location;

  /// The routing service.
  final Router _router;

  /// Value indicating whether a previous page in navigation history is available.
  bool get canGoBack => dom.window.history.length > 2;

  /// The URL to be used when the session history is empty.
  @Input('goBack')
  String fallbackUrl = '/';

  /// Navigates to the previous page in the session history if any, otherwise navigates to the [fallbackUrl].
  @HostListener('click')
  void onClick(dom.Event event) {
    event.preventDefault();
    if (canGoBack)
      _location.back();
    else
      _router.navigateByUrl(fallbackUrl.isEmpty ? '/' : fallbackUrl);
    _element.blur();
  }
}
