part of '../../ngx_core.dart';

/// Scrolls to a given anchor or position when the underlying element is clicked.
@Directive(exportAs: 'scrollTo', selector: '[scrollTo]')
class ScrollTo {
  /// Creates a new 'scrollTo' directive.
  ScrollTo(this._element, this._scroller);

  /// The underlying HTML element.
  final dom.Element _element;

  /// The scrolling service.
  final ViewportScroller _scroller;

  /// The top offset used when scrolling to an anchor.
  @Input()
  List<num> scrollOffset = [0, 0];

  /// The anchor or position to scroll to.
  @Input('scrollTo')
  dynamic scrollPosition = [0, 0];

  /// Value indicating whether to use a smooth scrolling.
  @Input()
  bool smoothScroll = true;

  /// Scrolls to the given anchor or position.
  @HostListener('click')
  void onClick(dom.Event event) {
    event.preventDefault();
    if (scrollPosition is String && scrollPosition.isEmpty)
      scrollPosition = [0, 0];
    if (scrollPosition is List<num>)
      _scroller.scrollToPosition(
          Point(scrollPosition.first, scrollPosition.last),
          smoothScroll: smoothScroll);
    else
      _scroller.scrollToAnchor(scrollPosition.toString(),
          offset: Point(scrollOffset.first, scrollOffset.last),
          smoothScroll: smoothScroll);
    _element.blur();
  }
}
