part of '../../ngx_core.dart';

/// Represents information relevant to pagination of data items.
class Pagination {
  /// Creates a new pagination.
  Pagination(
      {this.page = 0,
      this.pageCount = 0,
      this.pageSize = 0,
      this.totalCount = 0});

  /// Creates a new pagination from the specified HTTP [headers].
  Pagination.fromHttpHeaders(Map<String, String> headers)
      : this(
            page: int.tryParse(headers[pageHeader] ?? '0', radix: 10) ?? 0,
            pageCount:
                int.tryParse(headers[pageCountHeader] ?? '0', radix: 10) ?? 0,
            pageSize:
                int.tryParse(headers[pageSizeHeader] ?? '0', radix: 10) ?? 0,
            totalCount:
                int.tryParse(headers[totalCountHeader] ?? '0', radix: 10) ?? 0);

  /// The name of the HTTP header storing the page count.
  static String pageCountHeader = 'x-pagination-page-count';

  /// The name of the HTTP header storing the current page index.
  static String pageHeader = 'x-pagination-current-page';

  /// The name of the parameter storing the current page index.
  static String pageParam = 'page';

  /// The name of the HTTP header storing the page size.
  static String pageSizeHeader = 'x-pagination-per-page';

  /// The name of the parameter storing the page size.
  static String pageSizeParam = 'per-page';

  /// The name of the HTTP header storing the total count.
  static String totalCountHeader = 'x-pagination-total-count';

  /// The current page number.
  int page;

  /// The number of pages.
  int pageCount;

  /// The number of items per page.
  int pageSize;

  /// The total number of items.
  int totalCount;

  /// Converts this object to query parameters.
  Map<String, String> toQueryParameters() {
    final params = <String, String>{};
    if (page > 0) params[pageParam] = page.toString();
    if (pageSize > 0) params[pageSizeParam] = pageSize.toString();
    return params;
  }
}
