part of '../../ngx_core.dart';

/// Represents information relevant to sorting of data items.
class Sort {
  /// Creates a new sort.
  Sort(Map<String, SortDirection> attributes,
      {this.separator = ',', this.sortParam = 'sort'})
      : attributes = attributes ?? <String, SortDirection>{};

  /// A map specifying the attributes to be sorted and their sort direction.
  final Map<String, SortDirection> attributes;

  /// The character used to separate different attributes that need to be sorted by.
  String separator;

  /// The name of the parameter that specifies which attributes to be sorted in which direction.
  String sortParam;

  /// Converts this object to query parameters.
  Map<String, String> toQueryParameters() {
    final values = attributes.entries
        .map((entry) =>
            '${entry.value == SortDirection.ascending ? '' : '-'}${entry.key}')
        .toList();
    return values.isEmpty
        ? <String, String>{}
        : {sortParam: values.join(separator)};
  }
}

/// Specifies the direction of a sort parameter.
enum SortDirection {
  /// The sort is ascending.
  ascending,

  /// The sort is descending.
  descending
}
