part of '../../ngx_core.dart';

/// Finds links in text input and turns them into HTML links.
@Pipe('autolink')
class AutoLinkPipe implements PipeTransform {
  /// Finds links in the specified [value] and turns them into HTML links.
  /// An optional [target] indicates to the window or named frame to open links in.
  String transform(String value, [String target = '']) {
    final mailtoRegex = RegExp(r'^mailto:', caseSensitive: false);
    final urlRegex = RegExp(
        r'((s?ftp|ftps?|https?)://|(www\.)|(mailto:)?[A-Za-z0-9._%+-]+@)\S*[^\s.;,(){}<>"\u201d\u2019]',
        caseSensitive: false);

    var text = value;
    var match = urlRegex.firstMatch(text);

    final html = StringBuffer();
    while (match != null) {
      html.write(text.substring(0, match.start));

      var url = match.group(0);
      if (match.group(2) == null && match.group(4) == null)
        url = '${match.group(3) != null ? 'http://' : 'mailto:'}$url';

      html.write('<a href="${url.replaceAll('"', '&quot;')}"');
      if (target.isNotEmpty) html.write(' target="$target"');
      html.write('>${match.group(0).replaceFirst(mailtoRegex, '')}</a>');

      text = text.substring(match.start + match.group(0).length);
      match = urlRegex.firstMatch(text);
    }

    html.write(text);
    return html.toString();
  }
}
