part of '../../ngx_core.dart';

/// Bypasses security and trusts a given value to be safe.
@Pipe('safe')
class SafePipe implements PipeTransform {
  /// Creates a new pipe.
  SafePipe(this._sanitizer);

  /// The sanitization service.
  final DomSanitizationService _sanitizer;

  /// Trusts the specified [value] to be safe in the given security [context].
  SafeValue transform(String value,
      [TemplateSecurityContext context = TemplateSecurityContext.html]) {
    switch (context) {
      case TemplateSecurityContext.html:
        return _sanitizer.bypassSecurityTrustHtml(value);
      case TemplateSecurityContext.resourceUrl:
        return _sanitizer.bypassSecurityTrustResourceUrl(value);
      case TemplateSecurityContext.style:
        return _sanitizer.bypassSecurityTrustStyle(value);
      case TemplateSecurityContext.url:
        return _sanitizer.bypassSecurityTrustUrl(value);
      default:
        throw ArgumentError.value(context, 'context');
    }
  }
}
