part of '../../ngx_core.dart';

/// Provides a set of methods to handle common security-related tasks.
class Security {
  /// The algorithm which is used to generate password hashes.
  Hash passwordHashStrategy = sha512;

  /// Generates a secure hash from the given [password].
  String generatePasswordHash(String password) =>
      passwordHashStrategy.convert(utf8.encode(password)).toString();

  /// Generates a specified number of random bytes.
  Uint8List generateRandomKey(int length) =>
      dom.window.crypto.getRandomValues(Uint8List(length));

  /// Generates a random string of specified [length].
  String generateRandomString(int length) =>
      base64UrlEncode(generateRandomKey(length)).substring(0, length);

  /// Verifies a [password] against a [hash].
  bool validatePassword(String password, String hash) =>
      generatePasswordHash(password) == hash;
}
