import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [Pagination] class.
void main() => group('Pagination', () {
      group('.fromHttpHeaders()', () {
        test('should return an instance with default values for empty headers',
            () {
          final pagination = Pagination.fromHttpHeaders({});
          expect(pagination.page, 0);
          expect(pagination.pageCount, 0);
          expect(pagination.pageSize, 0);
          expect(pagination.totalCount, 0);
        });

        test('should return an initialized instance for the proper headers',
            () {
          final pagination = Pagination.fromHttpHeaders({
            Pagination.pageHeader: '123',
            Pagination.pageCountHeader: '128',
            Pagination.pageSizeHeader: '20',
            Pagination.totalCountHeader: '256'
          });

          expect(pagination.page, 123);
          expect(pagination.pageCount, 128);
          expect(pagination.pageSize, 20);
          expect(pagination.totalCount, 256);
        });

        test('should support custom HTTP headers', () {
          Pagination.pageHeader = 'x-page-index';
          Pagination.pageSizeHeader = 'x-count-per-page';

          final pagination = Pagination.fromHttpHeaders(
              {'x-count-per-page': '20', 'x-page-index': '123'});

          expect(pagination.page, equals(123));
          expect(pagination.pageSize, equals(20));
        });
      });

      group('.toQueryParameters()', () {
        test('should return the values of the current page and page size', () {
          final params =
              Pagination(page: 10, pageSize: 123).toQueryParameters();
          expect(params[Pagination.pageParam], '10');
          expect(params[Pagination.pageSizeParam], '123');
        });

        test('should support custom query parameters', () {
          Pagination.pageParam = 'pageIndex';
          Pagination.pageSizeParam = 'countPerPage';

          final params = Pagination(page: 1, pageSize: 20).toQueryParameters();
          expect(params.containsKey('page'), isFalse);
          expect(params.containsKey('per-page'), isFalse);
          expect(params['pageIndex'], '1');
          expect(params['countPerPage'], '20');
        });
      });
    });
