import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [AutoLinkPipe] class.
void main() => group('AutoLinkPipe', () {
      const text = '''
Pretty text with some links:
https://belin.io/index.html?search=foo#bar,
mailto:us@somewhere.org,
another@somewhere.org,
and one more: ftp://127.0.0.1/.
''';

      group('.transform()', () {
        test('should turn text links into HTML links', () {
          expect(
              AutoLinkPipe().transform(text),
              allOf(
                  contains(
                      '<a href="https://belin.io/index.html?search=foo#bar">https://belin.io/index.html?search=foo#bar</a>'),
                  contains(
                      '<a href="mailto:us@somewhere.org">us@somewhere.org</a>'),
                  contains(
                      '<a href="mailto:another@somewhere.org">another@somewhere.org</a>'),
                  contains('<a href="ftp://127.0.0.1/">ftp://127.0.0.1/</a>')));
        });

        test('should add a target attribute to the HTML links', () {
          expect(
              AutoLinkPipe().transform(text, '_blank'),
              allOf(
                  contains(
                      '<a href="https://belin.io/index.html?search=foo#bar" target="_blank">https://belin.io/index.html?search=foo#bar</a>'),
                  contains(
                      '<a href="mailto:us@somewhere.org" target="_blank">us@somewhere.org</a>'),
                  contains(
                      '<a href="mailto:another@somewhere.org" target="_blank">another@somewhere.org</a>'),
                  contains(
                      '<a href="ftp://127.0.0.1/" target="_blank">ftp://127.0.0.1/</a>')));
        });
      });
    });
