import 'package:angular/angular.dart';
import 'package:angular/security.dart';
import 'package:angular_test/angular_test.dart';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';
import 'safe_pipe_test.template.dart' as self;

/// The test component.
@Component(
    exports: [TemplateSecurityContext],
    pipes: [SafePipe],
    selector: 'test-component',
    template: '''
    <div id="safeHtml" [innerHTML]="value | safe: TemplateSecurityContext.html"></div>
    <div id="unsafeHtml" [innerHTML]="value"></div>
    <a id="safeUrl" [href]="value | safe: TemplateSecurityContext.url"></a>
    <a id="unsafeUrl" [href]="value"></a>
  ''')
class TestComponent {
  String value = '';
}

/// Tests the features of the [SafePipe] class.
void main() => group('SafePipe', () {
      final testBed =
          NgTestBed.forComponent<TestComponent>(self.TestComponentNgFactory);
      tearDown(disposeAnyRunningTest);

      group('.transform()', () {
        test('should trust the specified HTML to be safe', () async {
          final fixture = await testBed.create();
          await fixture
              .update((c) => c.value = '<script>alert("Foo!")</script>');
          expect(fixture.rootElement.querySelector('#safeHtml').innerHtml,
              '<script>alert("Foo!")</script>');
          expect(fixture.rootElement.querySelector('#unsafeHtml').innerHtml,
              isEmpty);
        });

        test('should trust the specified URL to be safe', () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c.value = 'javascript:alert("Foo!")');
          expect(
              fixture.rootElement.querySelector('#safeUrl').attributes['href'],
              'javascript:alert("Foo!")');
          expect(
              fixture.rootElement
                  .querySelector('#unsafeUrl')
                  .attributes['href'],
              'unsafe:javascript:alert("Foo!")');
        });
      });
    });
